summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_support.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_support.py')
-rw-r--r--Lib/test/test_support.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/test/test_support.py b/Lib/test/test_support.py
index c1abf1b..771b147 100644
--- a/Lib/test/test_support.py
+++ b/Lib/test/test_support.py
@@ -71,11 +71,11 @@ def findfile(file, here=__file__):
return file
def verify(condition, reason='test failed'):
"""Verify that condition is true. If not, raise an AssertionError.
The optinal argument reason can be given to provide
a better error text.
"""
if not condition:
- raise AssertionError(reason)
+ raise TestFailed(reason)
@@ -71,11 +71,11 @@ def findfile(file, here=__file__):
return file
def verify(condition, reason='test failed'):
- """Verify that condition is true. If not, raise an AssertionError.
+ """Verify that condition is true. If not, raise TestFailed.
The optinal argument reason can be given to provide
a better error text.